==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/sch_edit_task.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sch_view.lang.php');

// SECTION
$lang['hdr_schedule'] = 						"add or edit a task";


//HEADER
$lang['hdr_schedule'] = 						"add or edit a task";
$lang['hdr_group_schedule'] = 					"add or edit a group task for group 'GROUPTITLE'.";


// FORMS
$lang['form_no_start'] = 						"This task has no start date and time";
$lang['form_no_end'] = 							"This task has no end date and time";
$lang['form_label_comments'] = 					"Check to allow people to add comments to this task";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Task overview";
$lang['txt_overview_intro'] = 					"You can add a task to this community. A task is a thing to do. Add a small synopsis which is a one line description of the task to be used when displaying it in lists.";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your task. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm.";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the task on all lists. Choose one from the list below if desired.";
$lang['txt_publishing_intro'] = 				"Choose where you would like this task to be published to.";

?>

==> aroundme_0_6_9.zip: aroundme_0_6_9/aroundme/language/1/barnraiser_01/sch_edit_task.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_schedule_edit'] = 					"add or edit a task";
$lang['hdr_group_schedule_edit'] = 				"add or edit a group task";


// FORMS
$lang['form_no_start'] = 						"This task has no start date and time";
$lang['form_no_end'] = 							"This task has no end date and time";
$lang['form_label_comments'] = 					"Check to allow people to add comments to this task";


//BODY TEXT
$lang['txt_header_1'] = 						"1. Task overview";
$lang['txt_overview_intro'] = 					"You can add a task to this community. A task is a thing to do. Add a small synopsis which is a one line description of the task to be used when displaying it in lists.";
$lang['txt_date_intro'] = 						"Enter a start and end date and time for your task. You can use the popup calendar to enter a date and time or just type on in. The format is important. Please type the date as yyyy-dd-mm and the time as hh:mm.";
$lang['txt_image_intro'] = 						"A thumbnail (small) picture can be shown next to the task on all lists. Choose one from the list below if desired.";
$lang['txt_publishing_intro'] = 				"Choose where you would like this task to be published to.";

?>
